import { HttpClient } from "@angular/common/http";
import { Injectable } from "@angular/core";
import { EmployeesForAQualificationDTO, QualificationGetDTO, QualificationPostDTO } from "../models/skill";
import { Observable } from "rxjs";
import { EmployeeNameDataDTO } from "../models/mitarbeiter";
import { EmployeeService } from "./employee.service";

@Injectable({
  providedIn: 'root'
})
export class SkillService {
  deleteSkill(id: number) {
    this.getEmployeesBySkill(id).subscribe(employees => {
      for (let employee of employees.employees) {
        this.employeeService.removeSkillFromEmployee(id, employee.id);
      }
    });

    this.http.delete(`${SkillService.BASE_URL}/qualifications/${id}`).subscribe();
  }

  public static readonly BASE_URL = "http://127.0.0.1:8089";

  getToPutDto(skill: QualificationGetDTO): QualificationPostDTO {
    return {
      skill: skill.skill,
    }
  }

  constructor(private http: HttpClient, private employeeService: EmployeeService) {

  }

  updateSkill(skill: QualificationGetDTO) {
    this.http.put(`${SkillService.BASE_URL}/qualifications/${skill.id}`, this.getToPutDto(skill)).subscribe();
  }

  getAllSkills(): Observable<Array<QualificationGetDTO>> {
    return this.http.get<Array<QualificationGetDTO>>(`${SkillService.BASE_URL}/qualifications`);
  }

  getEmployeesBySkill(id: number): Observable<EmployeesForAQualificationDTO> {
    return this.http.get<EmployeesForAQualificationDTO>(`${SkillService.BASE_URL}/qualifications/${id}/employees`);
  }
}
